let receiptToastShown = false;

document.addEventListener("DOMContentLoaded", function () {
  const form = document.getElementById("receiptForm");
  const input = document.getElementById("receiptInput");
  const gallery = document.getElementById("receiptGallery");
  const progressContainer = document.getElementById("progressContainer");
  const progressBar = document.getElementById("progressBar");

  if (!form || !input || !gallery) return;

  form.addEventListener("submit", function (e) {
    e.preventDefault();

    const file = input.files[0];
    if (!file) {
      showToast("Nie wybrano pliku!", "warning");
      return;
    }

    const formData = new FormData();
    formData.append("receipt", file);

    const xhr = new XMLHttpRequest();
    xhr.open("POST", form.action, true);
    xhr.setRequestHeader("X-Requested-With", "XMLHttpRequest");

    xhr.upload.onprogress = function (e) {
      if (e.lengthComputable) {
        const percent = Math.round((e.loaded / e.total) * 100);
        progressBar.style.width = percent + "%";
        progressBar.textContent = percent + "%";
      }
    };

    xhr.onloadstart = function () {
      progressContainer.style.display = "block";
      progressBar.style.width = "0%";
      progressBar.textContent = "0%";
    };

    xhr.onloadend = function () {
      progressContainer.style.display = "none";
      progressBar.style.width = "0%";
      progressBar.textContent = "";
      input.value = "";
    };

    xhr.onreadystatechange = function () {
      if (xhr.readyState === XMLHttpRequest.DONE) {
        if (xhr.status === 200) {
          const res = JSON.parse(xhr.responseText);
          if (res.success && res.url) {

            fetch(window.location.href)
              .then(response => response.text())
              .then(html => {
                const parser = new DOMParser();
                const doc = parser.parseFromString(html, "text/html");
                const newGallery = doc.getElementById("receiptGallery");
                if (newGallery) {
                    gallery.innerHTML = newGallery.innerHTML;

                    if (!receiptToastShown) {
                        showToast("Wgrano paragon", "success");
                        receiptToastShown = true;
                    }
                    socket.emit("receipt_uploaded", {
                        list_id: LIST_ID,
                        url: res.url
                    });    
                }
              });
          } else {
            showToast(res.message || "Błąd podczas wgrywania.", "danger");
          }
        } else {
          showToast("Błąd serwera. Spróbuj ponownie.", "danger");
        }
      }
    };

    xhr.send(formData);
  });
});
